@@ -265,6 +265,9 @@ class Canvas:
                                         [x2, y2]]),
                                         fill = self.__parameters()['stroke_color'],
                                         width = self.__parameters()['stroke_width'])
+    @dispatch(Vector.Vector)
+    def line(self, v):
+        return self.line(0, 0, int(v.x), int(v.y))
     @dispatch(Vector.Vector, Vector.Vector)
     def line(self, v1, v2):
         return self.line(int(v1.x), int(v1.y), int(v2.x), int(v2.y))
@@ -372,6 +375,7 @@ class Canvas:
                                        text = text)
 
     # set a pixel
+    @dispatch(object, object, object)
     def point(self, x, y, color):
         for point_x, point_y in self.transform_coords([[x, y]]):
             if point_x >= 0 and point_y >= 0:
@@ -379,7 +383,10 @@ class Canvas:
                                         [x, y],
                                         [x + 1, y + 1]]),
                                         fill = color)
-                                        
+    @dispatch(Vector.Vector, object)
+    def point(self, v, color):
+        return self.point(v.x, v.y, color)
+
     # get RGB value of a pixel
     def get_pixel(self, x, y):
         x += self.__parameters()['center_x']
@@ -404,7 +411,7 @@ class Canvas:
             newheight = math.floor(height * scale)
             im = im.resize((newWidth, newheight), Image.ANTIALIAS)
 
-        self.__alpha_shapes.append(ImageTk.PhotoImage(im.rotate(self.__parameters()['rotate_deg'], expand = True)))
+        self.__alpha_shapes.append(ImageTk.PhotoImage(im.rotate(-self.__parameters()['rotate_deg'], expand = True)))
         return self.handle.create_image(self.transform_coords([[x, y]]),
                                         image = self.__alpha_shapes[-1],
                                         anchor = 'center')
