@@ -58,12 +58,13 @@ class EasyDraw(object):
         master.protocol("WM_DELETE_WINDOW", self.__on_closing)
 
         self.bg_color = kwargs.get('background', 'silver')
+        self.showGrid = kwargs.get('showGrid', False)
         self.canvas = Canvas.Canvas(master,
                             app = self,
                             width = self.width,
                             height = self.height,
                             background = self.bg_color,
-                            showGrid = kwargs.get('showGrid', False))
+                            showGrid = self.showGrid)
 
         self.tools = Tools.Tools()
         self.color = Color.Color()
@@ -137,6 +138,7 @@ class EasyDraw(object):
         self.mouse_top = e.y
 
     def __motion_event(self, event):
+        #self.__get_mouse_positions(event)
         if self.mouseMoveFunction:
             self.mouseMoveFunction(self)
 
@@ -180,7 +182,9 @@ class EasyDraw(object):
         if self.autoClear == True:
             self.canvas.clear('all')        
             self.canvas.clear_data()
-
+        else:
+            if self.showGrid:
+                self.canvas.showGrid()
         if callable(self.drawFunction):
             self.tick += 1
             mx = self.master.winfo_pointerx() - self.master.winfo_rootx()
